# datasets-genie

package for generating fake data in CSV, JSON, and XML formats. It can be used to create placeholder data for testing or demonstration purposes.

```
pip install datasets-genie
```

